@@ -12,7 +12,9 @@
 import os
 from PIL import Image
 from paddleocr import draw_ocr
-from appzoo.utils import cfg
+from appzoo.utils.zk_utils import get_zk_config
+
+fds_url = get_zk_config('/mipush/cfg')['fds_url']
 
 
 def get_image_size(image):
@@ -22,7 +24,7 @@ def get_image_size(image):
 
 def ocr_result_image(result, input_image, output_image='output_image.png'):
     if not os.path.exists('./simfang.ttf'):
-        os.system(f"wget -q {cfg['fds_url']}/data/simfang.ttf")
+        os.system(f"wget -q {fds_url}/data/simfang.ttf")
 
     image = Image.open(input_image).convert('RGB')
     boxes = [line[0] for line in result]
